==> EmailHarvester-2.0.0-py3-none-any.whl: EmailHarvester/core/splash.py <==
__author__ = 'herve.beraud'

DOOM = """

 _____                   _  _   _   _                                _
|  ___|                 (_)| | | | | |                              | |
| |__  _ __ ___    __ _  _ | | | |_| |  __ _  _ __ __   __ ___  ___ | |_  ___  _ __
|  __|| '_ ` _ \  / _` || || | |  _  | / _` || '__|\ \ / // _ \/ __|| __|/ _ \| '__|
| |___| | | | | || (_| || || | | | | || (_| || |    \ V /|  __/\__ \| |_|  __/| |
\____/|_| |_| |_| \__,_||_||_| \_| |_/ \__,_||_|     \_/  \___||___/ \__|\___||_|

    A tool to retrieve Domain email addresses from Search Engines | @maldevel
                                {}: {}
"""

GRAFFITI = """

___________              .__.__    ___ ___                                     __
\_   _____/ _____ _____  |__|  |  /   |   \_____ __________  __ ____   _______/  |_  ___________
 |    __)_ /     \\\\__  \ |  |  | /    ~    \__  \\\\_  __ \  \/ // __ \ /  ___/\   __\/ __ \_  __ \\
 |        \  Y Y  \/ __ \|  |  |_\    Y    // __ \|  | \/\   /\  ___/ \___ \  |  | \  ___/|  | \/
/_______  /__|_|  (____  /__|____/\___|_  /(____  /__|    \_/  \___  >____  > |__|  \___  >__|
        \/      \/     \/               \/      \/                 \/     \/            \/

    A tool to retrieve Domain email addresses from Search Engines | @maldevel
                            {}: {}
"""

FIRE = """
                               )
                        (   ( /(                               )
 (       )       )  (   )\  )\())    )  (     )      (      ( /(   (   (
 )\     (     ( /(  )\ ((_)((_)\  ( /(  )(   /((    ))\ (   )\()) ))\  )(
((_)    )\  ' )(_))((_) _   _((_) )(_))(()\ (_))\  /((_))\ (_))/ /((_)(()\\
| __| _((_)) ((_)_  (_)| | | || |((_)_  ((_)_)((_)(_)) ((_)| |_ (_))   ((_)
| _| | '  \()/ _` | | || | | __ |/ _` || '_|\ V / / -_)(_-<|  _|/ -_) | '_|
|___||_|_|_| \__,_| |_||_| |_||_|\__,_||_|   \_/  \___|/__/ \__|\___| |_|

    A tool to retrieve Domain email addresses from Search Engines | @maldevel
                            {}: {}
"""

==> EmailHarvester-2.0.1-py3-none-any.whl: EmailHarvester/core/splash.py <==
__author__ = 'herve.beraud'

DOOM = """

 _____                   _  _   _   _                                _
|  ___|                 (_)| | | | | |                              | |
| |__  _ __ ___    __ _  _ | | | |_| |  __ _  _ __ __   __ ___  ___ | |_  ___  _ __
|  __|| '_ ` _ \  / _` || || | |  _  | / _` || '__|\ \ / // _ \/ __|| __|/ _ \| '__|
| |___| | | | | || (_| || || | | | | || (_| || |    \ V /|  __/\__ \| |_|  __/| |
\____/|_| |_| |_| \__,_||_||_| \_| |_/ \__,_||_|     \_/  \___||___/ \__|\___||_|

    A tool to retrieve Domain email addresses from Search Engines | @4383 (Hervé Beraud)
                                {}: {}
"""

GRAFFITI = """

___________              .__.__    ___ ___                                     __
\_   _____/ _____ _____  |__|  |  /   |   \_____ __________  __ ____   _______/  |_  ___________
 |    __)_ /     \\\\__  \ |  |  | /    ~    \__  \\\\_  __ \  \/ // __ \ /  ___/\   __\/ __ \_  __ \\
 |        \  Y Y  \/ __ \|  |  |_\    Y    // __ \|  | \/\   /\  ___/ \___ \  |  | \  ___/|  | \/
/_______  /__|_|  (____  /__|____/\___|_  /(____  /__|    \_/  \___  >____  > |__|  \___  >__|
        \/      \/     \/               \/      \/                 \/     \/            \/

    A tool to retrieve Domain email addresses from Search Engines | @4383 (Hervé Beraud)
                            {}: {}
"""

FIRE = """
                               )
                        (   ( /(                               )
 (       )       )  (   )\  )\())    )  (     )      (      ( /(   (   (
 )\     (     ( /(  )\ ((_)((_)\  ( /(  )(   /((    ))\ (   )\()) ))\  )(
((_)    )\  ' )(_))((_) _   _((_) )(_))(()\ (_))\  /((_))\ (_))/ /((_)(()\\
| __| _((_)) ((_)_  (_)| | | || |((_)_  ((_)_)((_)(_)) ((_)| |_ (_))   ((_)
| _| | '  \()/ _` | | || | | __ |/ _` || '_|\ V / / -_)(_-<|  _|/ -_) | '_|
|___||_|_|_| \__,_| |_||_| |_||_|\__,_||_|   \_/  \___|/__/ \__|\___| |_|

    A tool to retrieve Domain email addresses from Search Engines | @4383 (Hervé Beraud)
                            {}: {}
"""
